==> haskell-persistent-test-2.13.1.3-9-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-K6YkKOzvlyqmdQsLA8K5m
key:                  persistent-test-2.13.1.3-K6YkKOzvlyqmdQsLA8K5m
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  a641ed4fc5c578a43e253d72e44ffb3f
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-K6YkKOzvlyqmdQsLA8K5m
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    QuickCheck-2.14.3-7KAyoz665FX6hCYaBEoJHk
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    blaze-html-0.9.1.2-A4gJO8svmvJ2veOR7qZVA9 bytestring-0.11.4.0
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s containers-0.6.5.1
    exceptions-0.10.4 hspec-2.10.9-8EhfN4d9WbFDPYIT2TWqlZ
    hspec-expectations-0.8.3-1zJ9Bt2UKIO1izJ8suxZW5
    http-api-data-0.5.1-U0fZvIQEYNFA9HYDriMAQ
    monad-control-1.0.3.1-3jkrHBLrPTk3GVH33R4YSx
    monad-logger-0.3.40-LHJ6PMq0aC62c6JpmSN96y mtl-2.2.2
    path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    persistent-2.14.5.1-9xnFRv8rkde2AoeFkZgfdg
    quickcheck-instances-0.3.30-6P73pelr9bTEQaqCyERB8u
    random-1.2.1.2-Ektqt59GIPs5HEoqAQJ00N
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 transformers-base-0.4.6-K4FFVfATjJJFq6PHdtpZIK
    unliftio-0.2.25.0-56sfjNmy7BWDzWuwznFqC8
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-test-2.13.1.3-29-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-HpRJroy4Iqt1iwuLToGUvS
key:                  persistent-test-2.13.1.3-HpRJroy4Iqt1iwuLToGUvS
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  61a7927d2b527b0d78a3e5dded9cb4c5
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-HpRJroy4Iqt1iwuLToGUvS
depends:
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    blaze-html-0.9.2.0-83dGvLlliMHJ0KNCx2IkOp bytestring-0.11.4.0
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x containers-0.6.5.1
    exceptions-0.10.4 hspec-2.10.9-KuS4B4SgPwm179O4lsuAOc
    hspec-expectations-0.8.3-53KTMpuZLbD4EdixkL29oj
    http-api-data-0.5.1-2BBAlVaYv607qWIFAG4oWp
    monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK
    monad-logger-0.3.40-2U6wkfWu2pa7AyH1VLvETa mtl-2.2.2
    path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    persistent-2.14.5.1-18Wt2qDE1QV8HG32f1oXLN
    quickcheck-instances-0.3.30-DCB0YUBPiLX2df5hCjMcnG
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN
    unliftio-0.2.25.0-LM0KsdTS0NHVSVsirPxfP
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
